@@ -20,7 +20,7 @@ from dotdrop.comparator import Comparator
 from dotdrop.importer import Importer
 from dotdrop.utils import get_tmpdir, removepath, \
     uniq_list, patch_ignores, dependencies_met, \
-    adapt_workers
+    adapt_workers, check_version
 from dotdrop.linktypes import LinkTypes
 from dotdrop.exceptions import YamlException, \
     UndefinedException, UnmetDependency
@@ -77,7 +77,7 @@ def _dotfile_update(opts, path, key=False):
     update a dotfile pointed by path
     if key is false or by key (in path)
     """
-    updater = Updater(opts.dotpath, opts.variables, opts.conf,
+    updater = Updater(opts.dotpath, opts.variables, opts.conf, opts.profile,
                       dry=opts.dry, safe=opts.safe, debug=opts.debug,
                       ignore=opts.update_ignore,
                       showpatch=opts.update_showpatch,
@@ -139,11 +139,14 @@ def _dotfile_compare(opts, dotfile, tmp):
     ignores = patch_ignores(ignores, dotfile.dst, debug=opts.debug)
 
     insttmp = None
-    if dotfile.template and Templategen.is_template(src, ignore=ignores):
+    if dotfile.template and Templategen.is_template(src,
+                                                    ignore=ignores,
+                                                    debug=opts.debug):
         # install dotfile to temporary dir for compare
         ret, err, insttmp = inst.install_to_temp(templ, tmp, src, dotfile.dst,
                                                  is_template=True,
-                                                 chmod=dotfile.chmod)
+                                                 chmod=dotfile.chmod,
+                                                 set_create=True)
         if not ret:
             # failed to install to tmp
             line = '=> compare {} error: {}'
@@ -829,6 +832,9 @@ def main():
         LOG.dbg('\n\n')
     options_time = time.time() - time0
 
+    if opts.check_version:
+        check_version()
+
     time0 = time.time()
     ret, command = _exec_command(opts)
     cmd_time = time.time() - time0
